%define ver 4.9.11

Summary:	Automatic 3D tetrahedral mesh generator
Name:		netgen
Version:	%{ver}
Release:	2
License:	LGPL
Group:		Applications/Library
Source:		%{name}-%{ver}.tar.bz2
Patch:		occ-6.3.0.patch
Patch1:		gcc-4.7.patch
#URL:		http://www.hpfem.jku.at/netgen/
URL:		http://sourceforge.net/projects/netgen-mesher/
BuildRoot:	/var/tmp/%{name}-%{version}-root-%(id -u -n)
BuildArch:	i386 i486 i586 i686 x86_64
Requires:	tcl, tk, tix
BuildRequires:  tcl-devel, tk-devel, tix-devel, gcc-c++, togl1.7
#%{?fc4:BuildRequires: compat-gcc-32-c++}
#%{?fc5:BuildRequires: compat-gcc-32-c++}
#%{?fc6:BuildRequires: compat-gcc-34-c++}
#%{?fc7:BuildRequires: compat-gcc-34-c++}
BuildRequires:	OpenCascadeModule >= 6.3
%ifarch x86_64
BuildRequires:	mesa-libGLU-devel
%endif
Prefix:		/opt/netgen

%description
NETGEN is an automatic 3D tetrahedral mesh generator. It accepts input from
constructive solid geometry (CSG) or boundary representation (BRep) from STL
file format. The connection to a geometry kernel allows the handling of IGES
and STEP files. NETGEN contains modules for mesh optimization and hierarchical
mesh refinement. Netgen is open source based on the LGPL license. It is
available for Unix/Linux and Windows.

NETGEN was developed mainly by Joachim Sch\"oberl within project grants from
the Austrian Science Fund FWF (Special Research Project "Numerical and Symbolic
Scientific Computing", Start Project "hp-FEM) at the Johannes Kepler University
Linz. Significant contributions were made by Johannes Gerstmayr (STL geometry)
Robert Gaisbauer (OpenCascade interface). 

%prep
# check to make sure that OCC is installed in /usr/local/occ
if ! test -d /usr/local/occ -a -d /usr/local/occ/lib -a -d /usr/local/occ/inc
then
    echo 1>&2 "Can't find OpenCascade in /usr/local/occ"
    false
fi
%setup -q -n %{name}-%{ver}
%patch -p1
%patch1 -p1

%build
# Note: use "-ffriend-injection -fpermissive" with GCC4?
#if test -x /usr/bin/gcc32; then
#    env MACHINE=LINUX make CC="gcc32"
#elif test -x /usr/bin/gcc34; then
#    env MACHINE=LINUX make CC="gcc34"
#else
#    env MACHINE=LINUX make CC="gcc"
#fi

# On x86_64 Tcl/Tk libs are missing on the link cmdline of ng_vol
# and here is a workaround

. %{_libdir}/tclConfig.sh
eval "TCL_LIB_SPEC=\"${TCL_LIB_SPEC}\""

. %{_libdir}/tkConfig.sh
eval "TK_LIB_SPEC=\"${TK_LIB_SPEC}\""

env LIBS="$TCL_LIB_SPEC $TK_LIB_SPEC" ./configure \
	--with-tcl=%{_libdir} --with-tk=%{_libdir} \
	--prefix=%{prefix} --enable-occ --with-occ=/usr/local/occ
make

%install
[ "$RPM_BUILD_ROOT" != "/" ] && rm -rf $RPM_BUILD_ROOT

make DESTDIR=$RPM_BUILD_ROOT install
strip $RPM_BUILD_ROOT%{prefix}/lib/*.so
cat <<END >$RPM_BUILD_ROOT%{prefix}/bin/ng
#!/bin/bash
export NETGENDIR=%{prefix}/bin
export LD_LIBRARY_PATH=%{prefix}/lib:/usr/lib/Togl1.7:/usr/local/occ/lib:
exec %{prefix}/bin/netgen "\$@"
END
chmod 755 $RPM_BUILD_ROOT%{prefix}/bin/ng
/bin/cp -af NEWS AUTHORS INSTALL ChangeLog README TODO doc/ng4.pdf tutorials \
	$RPM_BUILD_ROOT%{prefix}/share/doc/netgen/.

%post
/bin/rm -f /usr/bin/ng
ln -s %{prefix}/bin/ng /usr/bin/.

%clean
[ "$RPM_BUILD_ROOT" != "/" ] && rm -rf $RPM_BUILD_ROOT

%files
#%doc NEWS AUTHORS INSTALL ChangeLog README TODO doc/ng4.pdf tutorials
/opt/netgen/*



%changelog

* Sat Apr 25 2009 Zhang Linbo <zlb@lsec.cc.ac.cn>
- 4.9.7-1
  . create separate package for ngsolve
* Fri Apr 24 2009 Zhang Linbo <zlb@lsec.cc.ac.cn>
- 4.5-3
  . fix compiling with OCC-6.3.0
* Sat Apr 21 2007 Zhang Linbo <zlb@lsec.cc.ac.cn>
- 4.5-2
  . fix dependency issues on compat-gcc-3[24]-c++
